@@ -1,17 +1,59 @@
+#
+# python-bluetooth-mesh - Bluetooth Mesh for Python
+#
+# Copyright (C) 2019  SILVAIR sp. z o.o.
+#
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+#
+#
+# pylint: disable=W0223
+
 import enum
 
 from construct import (
-    Adapter, Select, Embedded, Rebuild,
-    BitStruct, Struct, Switch,
-    GreedyBytes, GreedyRange,
-    BitsInteger, Int24ul, Int16ul, Int8ul, Flag, Bytes,
-    ExprValidator, ValidationError,
-    this, len_, obj_, Padding
+    Adapter,
+    BitsInteger,
+    BitStruct,
+    Bytes,
+    Embedded,
+    ExprValidator,
+    Flag,
+    GreedyBytes,
+    GreedyRange,
+    Int8ul,
+    Int16ul,
+    Int24ul,
+    Padding,
+    Rebuild,
+    Select,
+    Struct,
+    Switch,
+    len_,
+    obj_,
+    this,
 )
 
 from .util import (
-    EnumAdapter, LogAdapter, BitList, Opcode, Reversed, RangeValidator,
-    EmbeddedBitStruct
+    BitList,
+    EmbeddedBitStruct,
+    EnumAdapter,
+    LogAdapter,
+    Opcode,
+    RangeValidator,
+    Reversed,
 )
 
 
@@ -49,16 +91,16 @@ class GATTNamespaceDescriptor(enum.IntEnum):
     EIGHTY_SEVENTH = 0x0057
     EIGHTY_SIXTH = 0x0056
     EIGHTY_THIRD = 0x0053
-    ELEVENTH = 0x000b
+    ELEVENTH = 0x000B
     EXTERNAL = 0x0110
-    FIFTEENTH = 0x000f
+    FIFTEENTH = 0x000F
     FIFTH = 0x0005
     FIFTIETH = 0x0032
-    FIFTY_EIGHTH = 0x003a
+    FIFTY_EIGHTH = 0x003A
     FIFTY_FIFTH = 0x0037
     FIFTY_FIRST = 0x0033
     FIFTY_FOURTH = 0x0036
-    FIFTY_NINTH = 0x003b
+    FIFTY_NINTH = 0x003B
     FIFTY_SECOND = 0x0034
     FIFTY_SEVENTH = 0x0039
     FIFTY_SIXTH = 0x0038
@@ -66,17 +108,17 @@ class GATTNamespaceDescriptor(enum.IntEnum):
     FIRST = 0x0001
     FLASH = 0x010A
     FORTIETH = 0x0028
-    FOURTEENTH = 0x000e
+    FOURTEENTH = 0x000E
     FOURTH = 0x0004
     FORTY_EIGHTH = 0x0030
-    FORTY_FIFTH = 0x002d
+    FORTY_FIFTH = 0x002D
     FORTY_FIRST = 0x0029
-    FORTY_FOURTH = 0x002c
+    FORTY_FOURTH = 0x002C
     FORTY_NINTH = 0x0031
-    FORTY_SECOND = 0x002a
-    FORTY_SEVENTH = 0x002f
-    FORTY_SIXTH = 0x002e
-    FORTY_THIRD = 0x002b
+    FORTY_SECOND = 0x002A
+    FORTY_SEVENTH = 0x002F
+    FORTY_SIXTH = 0x002E
+    FORTY_THIRD = 0x002B
     FRONT = 0x0100
     INSIDE = 0x010B
     INTERNAL = 0x010F
@@ -85,113 +127,113 @@ class GATTNamespaceDescriptor(enum.IntEnum):
     MAIN = 0x0106
     NINETEENTH = 0x0013
     NINTH = 0x0009
-    NINETIETH = 0x005a
+    NINETIETH = 0x005A
     NINETY_EIGHTH = 0x0062
-    NINETY_FIFTH = 0x005f
-    NINETY_FIRST = 0x005b
-    NINETY_FOURTH = 0x005e
+    NINETY_FIFTH = 0x005F
+    NINETY_FIRST = 0x005B
+    NINETY_FOURTH = 0x005E
     NINETY_NINTH = 0x0063
-    NINETY_SECOND = 0x005c
+    NINETY_SECOND = 0x005C
     NINETY_SEVENTH = 0x0061
     NINETY_SIXTH = 0x0060
-    NINETY_THIRD = 0x005d
+    NINETY_THIRD = 0x005D
     ONE_HUNDRED_AND_EIGHTEENTH = 0x0076
-    ONE_HUNDRED_AND_EIGHTH = 0x006c
-    ONE_HUNDRED_AND_EIGHTY_EIGHTH = 0x00bc
-    ONE_HUNDRED_AND_EIGHTY_FIFTH = 0x00b9
-    ONE_HUNDRED_AND_EIGHTY_FIRST = 0x00b5
-    ONE_HUNDRED_AND_EIGHTY_FOURTH = 0x00b8
-    ONE_HUNDRED_AND_EIGHTY_NINTH = 0x00bd
-    ONE_HUNDRED_AND_EIGHTY_SECOND = 0x00b6
-    ONE_HUNDRED_AND_EIGHTY_SEVENTH = 0x00bb
-    ONE_HUNDRED_AND_EIGHTY_SIXTH = 0x00ba
-    ONE_HUNDRED_AND_EIGHTY_THIRD = 0x00b7
-    ONE_HUNDRED_AND_ELEVENTH = 0x006f
+    ONE_HUNDRED_AND_EIGHTH = 0x006C
+    ONE_HUNDRED_AND_EIGHTY_EIGHTH = 0x00BC
+    ONE_HUNDRED_AND_EIGHTY_FIFTH = 0x00B9
+    ONE_HUNDRED_AND_EIGHTY_FIRST = 0x00B5
+    ONE_HUNDRED_AND_EIGHTY_FOURTH = 0x00B8
+    ONE_HUNDRED_AND_EIGHTY_NINTH = 0x00BD
+    ONE_HUNDRED_AND_EIGHTY_SECOND = 0x00B6
+    ONE_HUNDRED_AND_EIGHTY_SEVENTH = 0x00BB
+    ONE_HUNDRED_AND_EIGHTY_SIXTH = 0x00BA
+    ONE_HUNDRED_AND_EIGHTY_THIRD = 0x00B7
+    ONE_HUNDRED_AND_ELEVENTH = 0x006F
     ONE_HUNDRED_AND_FIFTEENTH = 0x0073
     ONE_HUNDRED_AND_FIFTH = 0x0069
-    ONE_HUNDRED_AND_FIFTY_EIGHTH = 0x009e
-    ONE_HUNDRED_AND_FIFTY_FIFTH = 0x009b
+    ONE_HUNDRED_AND_FIFTY_EIGHTH = 0x009E
+    ONE_HUNDRED_AND_FIFTY_FIFTH = 0x009B
     ONE_HUNDRED_AND_FIFTY_FIRST = 0x0097
-    ONE_HUNDRED_AND_FIFTY_FOURTH = 0x009a
-    ONE_HUNDRED_AND_FIFTY_NINTH = 0x009f
+    ONE_HUNDRED_AND_FIFTY_FOURTH = 0x009A
+    ONE_HUNDRED_AND_FIFTY_NINTH = 0x009F
     ONE_HUNDRED_AND_FIFTY_SECOND = 0x0098
-    ONE_HUNDRED_AND_FIFTY_SEVENTH = 0x009d
-    ONE_HUNDRED_AND_FIFTY_SIXTH = 0x009c
+    ONE_HUNDRED_AND_FIFTY_SEVENTH = 0x009D
+    ONE_HUNDRED_AND_FIFTY_SIXTH = 0x009C
     ONE_HUNDRED_AND_FIFTY_THIRD = 0x0099
     ONE_HUNDRED_AND_FIRST = 0x0065
     ONE_HUNDRED_AND_FOURTEENTH = 0x0072
     ONE_HUNDRED_AND_FOURTH = 0x0068
     ONE_HUNDRED_AND_FORTY_EIGHTH = 0x0094
     ONE_HUNDRED_AND_FORTY_FIFTH = 0x0091
-    ONE_HUNDRED_AND_FORTY_FIRST = 0x008d
+    ONE_HUNDRED_AND_FORTY_FIRST = 0x008D
     ONE_HUNDRED_AND_FORTY_FOURTH = 0x0090
     ONE_HUNDRED_AND_FORTY_NINTH = 0x0095
-    ONE_HUNDRED_AND_FORTY_SECOND = 0x008e
+    ONE_HUNDRED_AND_FORTY_SECOND = 0x008E
     ONE_HUNDRED_AND_FORTY_SEVENTH = 0x0093
     ONE_HUNDRED_AND_FORTY_SIXTH = 0x0092
-    ONE_HUNDRED_AND_FORTY_THIRD = 0x008f
+    ONE_HUNDRED_AND_FORTY_THIRD = 0x008F
     ONE_HUNDRED_AND_NINETEENTH = 0x0077
-    ONE_HUNDRED_AND_NINTH = 0x006d
-    ONE_HUNDRED_AND_NINETY_EIGHTH = 0x00c6
-    ONE_HUNDRED_AND_NINETY_FIFTH = 0x00c3
-    ONE_HUNDRED_AND_NINETY_FIRST = 0x00bf
-    ONE_HUNDRED_AND_NINETY_FOURTH = 0x00c2
-    ONE_HUNDRED_AND_NINETY_NINTH = 0x00c7
-    ONE_HUNDRED_AND_NINETY_SECOND = 0x00c0
-    ONE_HUNDRED_AND_NINETY_SEVENTH = 0x00c5
-    ONE_HUNDRED_AND_NINETY_SIXTH = 0x00c4
-    ONE_HUNDRED_AND_NINETY_THIRD = 0x00c1
+    ONE_HUNDRED_AND_NINTH = 0x006D
+    ONE_HUNDRED_AND_NINETY_EIGHTH = 0x00C6
+    ONE_HUNDRED_AND_NINETY_FIFTH = 0x00C3
+    ONE_HUNDRED_AND_NINETY_FIRST = 0x00BF
+    ONE_HUNDRED_AND_NINETY_FOURTH = 0x00C2
+    ONE_HUNDRED_AND_NINETY_NINTH = 0x00C7
+    ONE_HUNDRED_AND_NINETY_SECOND = 0x00C0
+    ONE_HUNDRED_AND_NINETY_SEVENTH = 0x00C5
+    ONE_HUNDRED_AND_NINETY_SIXTH = 0x00C4
+    ONE_HUNDRED_AND_NINETY_THIRD = 0x00C1
     ONE_HUNDRED_AND_SECOND = 0x0066
     ONE_HUNDRED_AND_SEVENTEENTH = 0x0075
-    ONE_HUNDRED_AND_SEVENTH = 0x006b
-    ONE_HUNDRED_AND_SEVENTY_EIGHTH = 0x00b2
-    ONE_HUNDRED_AND_SEVENTY_FIFTH = 0x00af
-    ONE_HUNDRED_AND_SEVENTY_FIRST = 0x00ab
-    ONE_HUNDRED_AND_SEVENTY_FOURTH = 0x00ae
-    ONE_HUNDRED_AND_SEVENTY_NINTH = 0x00b3
-    ONE_HUNDRED_AND_SEVENTY_SECOND = 0x00ac
-    ONE_HUNDRED_AND_SEVENTY_SEVENTH = 0x00b1
-    ONE_HUNDRED_AND_SEVENTY_SIXTH = 0x00b0
-    ONE_HUNDRED_AND_SEVENTY_THIRD = 0x00ad
+    ONE_HUNDRED_AND_SEVENTH = 0x006B
+    ONE_HUNDRED_AND_SEVENTY_EIGHTH = 0x00B2
+    ONE_HUNDRED_AND_SEVENTY_FIFTH = 0x00AF
+    ONE_HUNDRED_AND_SEVENTY_FIRST = 0x00AB
+    ONE_HUNDRED_AND_SEVENTY_FOURTH = 0x00AE
+    ONE_HUNDRED_AND_SEVENTY_NINTH = 0x00B3
+    ONE_HUNDRED_AND_SEVENTY_SECOND = 0x00AC
+    ONE_HUNDRED_AND_SEVENTY_SEVENTH = 0x00B1
+    ONE_HUNDRED_AND_SEVENTY_SIXTH = 0x00B0
+    ONE_HUNDRED_AND_SEVENTY_THIRD = 0x00AD
     ONE_HUNDRED_AND_SIXTEENTH = 0x0074
-    ONE_HUNDRED_AND_SIXTH = 0x006a
-    ONE_HUNDRED_AND_SIXTY_EIGHTH = 0x00a8
-    ONE_HUNDRED_AND_SIXTY_FIFTH = 0x00a5
-    ONE_HUNDRED_AND_SIXTY_FIRST = 0x00a1
-    ONE_HUNDRED_AND_SIXTY_FOURTH = 0x00a4
-    ONE_HUNDRED_AND_SIXTY_NINTH = 0x00a9
-    ONE_HUNDRED_AND_SIXTY_SECOND = 0x00a2
-    ONE_HUNDRED_AND_SIXTY_SEVENTH = 0x00a7
-    ONE_HUNDRED_AND_SIXTY_SIXTH = 0x00a6
-    ONE_HUNDRED_AND_SIXTY_THIRD = 0x00a3
-    ONE_HUNDRED_AND_TENTH = 0x006e
+    ONE_HUNDRED_AND_SIXTH = 0x006A
+    ONE_HUNDRED_AND_SIXTY_EIGHTH = 0x00A8
+    ONE_HUNDRED_AND_SIXTY_FIFTH = 0x00A5
+    ONE_HUNDRED_AND_SIXTY_FIRST = 0x00A1
+    ONE_HUNDRED_AND_SIXTY_FOURTH = 0x00A4
+    ONE_HUNDRED_AND_SIXTY_NINTH = 0x00A9
+    ONE_HUNDRED_AND_SIXTY_SECOND = 0x00A2
+    ONE_HUNDRED_AND_SIXTY_SEVENTH = 0x00A7
+    ONE_HUNDRED_AND_SIXTY_SIXTH = 0x00A6
+    ONE_HUNDRED_AND_SIXTY_THIRD = 0x00A3
+    ONE_HUNDRED_AND_TENTH = 0x006E
     ONE_HUNDRED_AND_THIRD = 0x0067
     ONE_HUNDRED_AND_THIRTEENTH = 0x0071
-    ONE_HUNDRED_AND_THIRTY_EIGHTH = 0x008a
+    ONE_HUNDRED_AND_THIRTY_EIGHTH = 0x008A
     ONE_HUNDRED_AND_THIRTY_FIFTH = 0x0087
     ONE_HUNDRED_AND_THIRTY_FIRST = 0x0083
     ONE_HUNDRED_AND_THIRTY_FOURTH = 0x0086
-    ONE_HUNDRED_AND_THIRTY_NINTH = 0x008b
+    ONE_HUNDRED_AND_THIRTY_NINTH = 0x008B
     ONE_HUNDRED_AND_THIRTY_SECOND = 0x0084
     ONE_HUNDRED_AND_THIRTY_SEVENTH = 0x0089
     ONE_HUNDRED_AND_THIRTY_SIXTH = 0x0088
     ONE_HUNDRED_AND_THIRTY_THIRD = 0x0085
     ONE_HUNDRED_AND_TWELVETH = 0x0070
     ONE_HUNDRED_AND_TWENTY_EIGHTH = 0x0080
-    ONE_HUNDRED_AND_TWENTY_FIFTH = 0x007d
+    ONE_HUNDRED_AND_TWENTY_FIFTH = 0x007D
     ONE_HUNDRED_AND_TWENTY_FIRST = 0x0079
-    ONE_HUNDRED_AND_TWENTY_FOURTH = 0x007c
+    ONE_HUNDRED_AND_TWENTY_FOURTH = 0x007C
     ONE_HUNDRED_AND_TWENTY_NINTH = 0x0081
-    ONE_HUNDRED_AND_TWENTY_SECOND = 0x007a
-    ONE_HUNDRED_AND_TWENTY_SEVENTH = 0x007f
-    ONE_HUNDRED_AND_TWENTY_SIXTH = 0x007e
-    ONE_HUNDRED_AND_TWENTY_THIRD = 0x007b
-    ONE_HUNDRED_EIGHTIETH = 0x00b4
+    ONE_HUNDRED_AND_TWENTY_SECOND = 0x007A
+    ONE_HUNDRED_AND_TWENTY_SEVENTH = 0x007F
+    ONE_HUNDRED_AND_TWENTY_SIXTH = 0x007E
+    ONE_HUNDRED_AND_TWENTY_THIRD = 0x007B
+    ONE_HUNDRED_EIGHTIETH = 0x00B4
     ONE_HUNDRED_FIFTIETH = 0x0096
-    ONE_HUNDRED_FORTIETH = 0x008c
-    ONE_HUNDRED_NINETIETH = 0x00be
-    ONE_HUNDRED_SEVENTIETH = 0x00aa
-    ONE_HUNDRED_SIXTIETH = 0x00a0
+    ONE_HUNDRED_FORTIETH = 0x008C
+    ONE_HUNDRED_NINETIETH = 0x00BE
+    ONE_HUNDRED_SEVENTIETH = 0x00AA
+    ONE_HUNDRED_SIXTIETH = 0x00A0
     ONE_HUNDRED_THIRTIETH = 0x0082
     ONE_HUNDRED_TWENTIETH = 0x0078
     ONE_HUNDREDTH = 0x0064
@@ -201,35 +243,35 @@ class GATTNamespaceDescriptor(enum.IntEnum):
     SEVENTEENTH = 0x0011
     SEVENTH = 0x0007
     SEVENTIETH = 0x0046
-    SEVENTY_EIGHTH = 0x004e
-    SEVENTY_FIFTH = 0x004b
+    SEVENTY_EIGHTH = 0x004E
+    SEVENTY_FIFTH = 0x004B
     SEVENTY_FIRST = 0x0047
-    SEVENTY_FOURTH = 0x004a
-    SEVENTY_NINTH = 0x004f
+    SEVENTY_FOURTH = 0x004A
+    SEVENTY_NINTH = 0x004F
     SEVENTY_SECOND = 0x0048
-    SEVENTY_SEVENTH = 0x004d
-    SEVENTY_SIXTH = 0x004c
+    SEVENTY_SEVENTH = 0x004D
+    SEVENTY_SIXTH = 0x004C
     SEVENTY_THIRD = 0x0049
     SIXTEENTH = 0x0010
     SIXTH = 0x0006
-    SIXTIETH = 0x003c
+    SIXTIETH = 0x003C
     SIXTY_EIGHTH = 0x0044
     SIXTY_FIFTH = 0x0041
-    SIXTY_FIRST = 0x003d
+    SIXTY_FIRST = 0x003D
     SIXTY_FOURTH = 0x0040
     SIXTY_NINTH = 0x0045
-    SIXTY_SECOND = 0x003e
+    SIXTY_SECOND = 0x003E
     SIXTY_SEVENTH = 0x0043
     SIXTY_SIXTH = 0x0042
-    SIXTY_THIRD = 0x003f
+    SIXTY_THIRD = 0x003F
     SUPPLEMENTARY = 0x0109
-    TENTH = 0x000a
+    TENTH = 0x000A
     THIRD = 0x0003
-    THIRTEENTH = 0x000d
-    THIRTIETH = 0x001e
+    THIRTEENTH = 0x000D
+    THIRTIETH = 0x001E
     THIRTY_EIGHTH = 0x0026
     THIRTY_FIFTH = 0x0023
-    THIRTY_FIRST = 0x001f
+    THIRTY_FIRST = 0x001F
     THIRTY_FOURTH = 0x0022
     THIRTY_NINTH = 0x0027
     THIRTY_SECOND = 0x0020
@@ -237,73 +279,73 @@ class GATTNamespaceDescriptor(enum.IntEnum):
     THIRTY_SIXTH = 0x0024
     THIRTY_THIRD = 0x0021
     TOP = 0x0102
-    TWELVETH = 0x000c
+    TWELVETH = 0x000C
     TWENTIETH = 0x0014
-    TWENTY_EIGHTH = 0x001c
+    TWENTY_EIGHTH = 0x001C
     TWENTY_FIFTH = 0x0019
     TWENTY_FIRST = 0x0015
     TWENTY_FOURTH = 0x0018
-    TWENTY_NINTH = 0x001d
+    TWENTY_NINTH = 0x001D
     TWENTY_SECOND = 0x0016
-    TWENTY_SEVENTH = 0x001b
-    TWENTY_SIXTH = 0x001a
+    TWENTY_SEVENTH = 0x001B
+    TWENTY_SIXTH = 0x001A
     TWENTY_THIRD = 0x0017
-    TWO_HUNDRED_AND_EIGHTEENTH = 0x00da
-    TWO_HUNDRED_AND_EIGHTH = 0x00d0
-    TWO_HUNDRED_AND_ELEVENTH = 0x00d3
-    TWO_HUNDRED_AND_FIFTEENTH = 0x00d7
-    TWO_HUNDRED_AND_FIFTH = 0x00cd
-    TWO_HUNDRED_AND_FIFTY_FIFTH = 0x00ff
-    TWO_HUNDRED_AND_FIFTY_FIRST = 0x00fb
-    TWO_HUNDRED_AND_FIFTY_FOURTH = 0x00fe
-    TWO_HUNDRED_AND_FIFTY_SECOND = 0x00fc
-    TWO_HUNDRED_AND_FIFTY_THIRD = 0x00fd
-    TWO_HUNDRED_AND_FIRST = 0x00c9
-    TWO_HUNDRED_AND_FOURTEENTH = 0x00d6
-    TWO_HUNDRED_AND_FOURTH = 0x00cc
-    TWO_HUNDRED_AND_FORTY_EIGHTH = 0x00f8
-    TWO_HUNDRED_AND_FORTY_FIFTH = 0x00f5
-    TWO_HUNDRED_AND_FORTY_FIRST = 0x00f1
-    TWO_HUNDRED_AND_FORTY_FOURTH = 0x00f4
-    TWO_HUNDRED_AND_FORTY_NINTH = 0x00f9
-    TWO_HUNDRED_AND_FORTY_SECOND = 0x00f2
-    TWO_HUNDRED_AND_FORTY_SEVENTH = 0x00f7
-    TWO_HUNDRED_AND_FORTY_SIXTH = 0x00f6
-    TWO_HUNDRED_AND_FORTY_THIRD = 0x00f3
-    TWO_HUNDRED_AND_NINETEENTH = 0x00db
-    TWO_HUNDRED_AND_NINTH = 0x00d1
-    TWO_HUNDRED_AND_SECOND = 0x00ca
-    TWO_HUNDRED_AND_SEVENTEENTH = 0x00d9
-    TWO_HUNDRED_AND_SEVENTH = 0x00cf
-    TWO_HUNDRED_AND_SIXTEENTH = 0x00d8
-    TWO_HUNDRED_AND_SIXTH = 0x00ce
-    TWO_HUNDRED_AND_TENTH = 0x00d2
-    TWO_HUNDRED_AND_THIRD = 0x00cb
-    TWO_HUNDRED_AND_THIRTEENTH = 0x00d5
-    TWO_HUNDRED_AND_THIRTY_EIGHTH = 0x00ee
-    TWO_HUNDRED_AND_THIRTY_FIFTH = 0x00eb
-    TWO_HUNDRED_AND_THIRTY_FIRST = 0x00e7
-    TWO_HUNDRED_AND_THIRTY_FOURTH = 0x00ea
-    TWO_HUNDRED_AND_THIRTY_NINTH = 0x00ef
-    TWO_HUNDRED_AND_THIRTY_SECOND = 0x00e8
-    TWO_HUNDRED_AND_THIRTY_SEVENTH = 0x00ed
-    TWO_HUNDRED_AND_THIRTY_SIXTH = 0x00ec
-    TWO_HUNDRED_AND_THIRTY_THIRD = 0x00e9
-    TWO_HUNDRED_AND_TWELVETH = 0x00d4
-    TWO_HUNDRED_AND_TWENTY_EIGHTH = 0x00e4
-    TWO_HUNDRED_AND_TWENTY_FIFTH = 0x00e1
-    TWO_HUNDRED_AND_TWENTY_FIRST = 0x00dd
-    TWO_HUNDRED_AND_TWENTY_FOURTH = 0x00e0
-    TWO_HUNDRED_AND_TWENTY_NINTH = 0x00e5
-    TWO_HUNDRED_AND_TWENTY_SECOND = 0x00de
-    TWO_HUNDRED_AND_TWENTY_SEVENTH = 0x00e3
-    TWO_HUNDRED_AND_TWENTY_SIXTH = 0x00e2
-    TWO_HUNDRED_AND_TWENTY_THIRD = 0x00df
-    TWO_HUNDRED_FIFTIETH = 0x00fa
-    TWO_HUNDRED_FORTIETH = 0x00f0
-    TWO_HUNDRED_THIRTIETH = 0x00e6
-    TWO_HUNDRED_TWENTIETH = 0x00dc
-    TWO_HUNDREDTH = 0x00c8
+    TWO_HUNDRED_AND_EIGHTEENTH = 0x00DA
+    TWO_HUNDRED_AND_EIGHTH = 0x00D0
+    TWO_HUNDRED_AND_ELEVENTH = 0x00D3
+    TWO_HUNDRED_AND_FIFTEENTH = 0x00D7
+    TWO_HUNDRED_AND_FIFTH = 0x00CD
+    TWO_HUNDRED_AND_FIFTY_FIFTH = 0x00FF
+    TWO_HUNDRED_AND_FIFTY_FIRST = 0x00FB
+    TWO_HUNDRED_AND_FIFTY_FOURTH = 0x00FE
+    TWO_HUNDRED_AND_FIFTY_SECOND = 0x00FC
+    TWO_HUNDRED_AND_FIFTY_THIRD = 0x00FD
+    TWO_HUNDRED_AND_FIRST = 0x00C9
+    TWO_HUNDRED_AND_FOURTEENTH = 0x00D6
+    TWO_HUNDRED_AND_FOURTH = 0x00CC
+    TWO_HUNDRED_AND_FORTY_EIGHTH = 0x00F8
+    TWO_HUNDRED_AND_FORTY_FIFTH = 0x00F5
+    TWO_HUNDRED_AND_FORTY_FIRST = 0x00F1
+    TWO_HUNDRED_AND_FORTY_FOURTH = 0x00F4
+    TWO_HUNDRED_AND_FORTY_NINTH = 0x00F9
+    TWO_HUNDRED_AND_FORTY_SECOND = 0x00F2
+    TWO_HUNDRED_AND_FORTY_SEVENTH = 0x00F7
+    TWO_HUNDRED_AND_FORTY_SIXTH = 0x00F6
+    TWO_HUNDRED_AND_FORTY_THIRD = 0x00F3
+    TWO_HUNDRED_AND_NINETEENTH = 0x00DB
+    TWO_HUNDRED_AND_NINTH = 0x00D1
+    TWO_HUNDRED_AND_SECOND = 0x00CA
+    TWO_HUNDRED_AND_SEVENTEENTH = 0x00D9
+    TWO_HUNDRED_AND_SEVENTH = 0x00CF
+    TWO_HUNDRED_AND_SIXTEENTH = 0x00D8
+    TWO_HUNDRED_AND_SIXTH = 0x00CE
+    TWO_HUNDRED_AND_TENTH = 0x00D2
+    TWO_HUNDRED_AND_THIRD = 0x00CB
+    TWO_HUNDRED_AND_THIRTEENTH = 0x00D5
+    TWO_HUNDRED_AND_THIRTY_EIGHTH = 0x00EE
+    TWO_HUNDRED_AND_THIRTY_FIFTH = 0x00EB
+    TWO_HUNDRED_AND_THIRTY_FIRST = 0x00E7
+    TWO_HUNDRED_AND_THIRTY_FOURTH = 0x00EA
+    TWO_HUNDRED_AND_THIRTY_NINTH = 0x00EF
+    TWO_HUNDRED_AND_THIRTY_SECOND = 0x00E8
+    TWO_HUNDRED_AND_THIRTY_SEVENTH = 0x00ED
+    TWO_HUNDRED_AND_THIRTY_SIXTH = 0x00EC
+    TWO_HUNDRED_AND_THIRTY_THIRD = 0x00E9
+    TWO_HUNDRED_AND_TWELVETH = 0x00D4
+    TWO_HUNDRED_AND_TWENTY_EIGHTH = 0x00E4
+    TWO_HUNDRED_AND_TWENTY_FIFTH = 0x00E1
+    TWO_HUNDRED_AND_TWENTY_FIRST = 0x00DD
+    TWO_HUNDRED_AND_TWENTY_FOURTH = 0x00E0
+    TWO_HUNDRED_AND_TWENTY_NINTH = 0x00E5
+    TWO_HUNDRED_AND_TWENTY_SECOND = 0x00DE
+    TWO_HUNDRED_AND_TWENTY_SEVENTH = 0x00E3
+    TWO_HUNDRED_AND_TWENTY_SIXTH = 0x00E2
+    TWO_HUNDRED_AND_TWENTY_THIRD = 0x00DF
+    TWO_HUNDRED_FIFTIETH = 0x00FA
+    TWO_HUNDRED_FORTIETH = 0x00F0
+    TWO_HUNDRED_THIRTIETH = 0x00E6
+    TWO_HUNDRED_TWENTIETH = 0x00DC
+    TWO_HUNDREDTH = 0x00C8
     UNKNOWN = 0x0000
     UPPER = 0x0104
 
@@ -365,7 +407,9 @@ RelayAdapter = EnumAdapter(Int8ul, Relay)
 
 GATTNamespaceDescriptorAdapter = EnumAdapter(Int16ul, GATTNamespaceDescriptor)
 
-PublishFriendshipCredentialsFlagAdapter = EnumAdapter(Flag, PublishFriendshipCredentialsFlag)
+PublishFriendshipCredentialsFlagAdapter = EnumAdapter(
+    Flag, PublishFriendshipCredentialsFlag
+)
 
 StatusCodeAdapter = EnumAdapter(Int8ul, StatusCode)
 
@@ -375,6 +419,7 @@ FriendAdapter = EnumAdapter(Int8ul, Friend)
 
 TTL = RangeValidator(Int8ul, max_value=0x7F)
 
+# fmt: off
 SIGModelId = Struct(
     "model_id" / Int16ul,
 )
@@ -388,6 +433,7 @@ ModelId = Select(
     VendorModelId,
     SIGModelId
 )
+# fmt: on
 
 
 class AddressType(enum.Enum):
@@ -403,6 +449,8 @@ class AddressType(enum.Enum):
 
 
 def get_address_type(address):
+    # pylint: disable=R0911
+
     if address == 0x0000:
         return AddressType.UNASSIGNED
 
@@ -432,11 +480,11 @@ def get_address_type(address):
 
 def AddressTypeValidator(subcons, *allowed_types):
     return ExprValidator(
-        subcons,
-        lambda obj, ctx: get_address_type(obj) in allowed_types
+        subcons, lambda obj, ctx: get_address_type(obj) in allowed_types
     )
 
 
+# fmt: off
 UnassignedAddress = AddressTypeValidator(
     Int16ul,
     AddressType.UNASSIGNED
@@ -516,6 +564,7 @@ Retransmit = BitStruct(
     "interval_steps" / BitsInteger(5),
     "count" / BitsInteger(3),
 )
+# fmt: on
 
 
 class RetransmitAdapter(Adapter):
@@ -525,35 +574,36 @@ class RetransmitAdapter(Adapter):
         super(RetransmitAdapter, self).__init__(subcon)
 
     def _decode(self, obj, context, path):
-        return dict(count=obj['count'], interval=(obj['interval_steps']+1)*self.interval)
+        return dict(
+            count=obj["count"], interval=(obj["interval_steps"] + 1) * self.interval
+        )
 
     def _encode(self, obj, context, path):
-        return dict(count=obj['count'], interval_steps=int(round((obj['interval']/self.interval)-1)))
+        return dict(
+            count=obj["count"],
+            interval_steps=int(round((obj["interval"] / self.interval) - 1)),
+        )
 
 
-NetworkRetransmit = RetransmitAdapter(Retransmit, 10)  # (Network Retransmit Interval Steps + 1) * 10ms
+NetworkRetransmit = RetransmitAdapter(
+    Retransmit, 10
+)  # (Network Retransmit Interval Steps + 1) * 10ms
 
 RelayRetransmit = NetworkRetransmit  # (Relay Retransmit Interval Steps + 1) * 10ms
 
-PublishRetransmit = RetransmitAdapter(Retransmit, 50)  # (Publish Retransmit Interval Steps + 1) * 50ms
+PublishRetransmit = RetransmitAdapter(
+    Retransmit, 50
+)  # (Publish Retransmit Interval Steps + 1) * 50ms
 
 
 def DoubleKeyIndex(first, second):
     return EmbeddedBitStruct(
-        "_",
-        second / BitsInteger(12),
-        first / BitsInteger(12),
-        reversed=True
+        "_", second / BitsInteger(12), first / BitsInteger(12), reversed=True
     )
 
 
 def SingleKeyIndex(name):
-    return EmbeddedBitStruct(
-        "_",
-        Padding(4),
-        name / BitsInteger(12),
-        reversed=True
-    )
+    return EmbeddedBitStruct("_", Padding(4), name / BitsInteger(12), reversed=True)
 
 
 NetAndAppKeyIndex = DoubleKeyIndex("net_key_index", "app_key_index")
@@ -571,10 +621,10 @@ class KeyIndicesAdapter(Adapter):
         """
         ret = []
         for item in obj:
-            if 'last' in item:
-                ret += [item['last']]
+            if "last" in item:
+                ret += [item["last"]]
             else:
-                ret += [item['first'], item['second']]
+                ret += [item["first"], item["second"]]
         return sorted(ret)
 
     def _encode(self, obj, context, path):
@@ -593,6 +643,7 @@ class KeyIndicesAdapter(Adapter):
         return ret
 
 
+# fmt: off
 KeyIndices = KeyIndicesAdapter(
     GreedyRange(
         Select(
@@ -612,6 +663,7 @@ KeyIndices = KeyIndicesAdapter(
     )
 )
 KeyIndices.__construct_doc__ = GreedyRange(BitsInteger(12))
+# fmt: on
 
 
 class PublishPeriodStepResolution(enum.IntEnum):
@@ -621,6 +673,7 @@ class PublishPeriodStepResolution(enum.IntEnum):
     RESOLUTION_10_MIN = 0x3
 
 
+# fmt: off
 PublishPeriodStepResolutionAdapter = EnumAdapter(
     BitsInteger(2),
     PublishPeriodStepResolution
@@ -949,6 +1002,7 @@ ConfigNetworkTransmitGet = Struct()
 ConfigNetworkTransmitSet = NetworkRetransmit
 
 ConfigNetworkTransmitStatus = ConfigNetworkTransmitSet
+# fmt: on
 
 
 class ConfigOpcode(enum.IntEnum):
@@ -1025,6 +1079,7 @@ class ConfigOpcode(enum.IntEnum):
     VENDOR_MODEL_SUBSCRIPTION_LIST = 0x802C
 
 
+# fmt: off
 ConfigMessage = Struct(
     "opcode" / EnumAdapter(Opcode, ConfigOpcode),
     "params" / Switch(
@@ -1104,3 +1159,4 @@ ConfigMessage = Struct(
         }
     )
 )
+# fmt: on
